@@ -121,8 +121,7 @@ user_config = DotDict(dict(
 
     visualization = parser.getboolean('minpower', 'visualization'),
     logging_level = parser.getint('minpower', 'logging_level'),
-    logging_filename = parser.getboolean('minpower', 'logging_filename'),
-    problem_filename = parser.getboolean('minpower', 'problem_filename'),
+    problem_file = parser.getboolean('minpower', 'problem_file'),
     output_prefix = parser.getboolean('minpower', 'output_prefix'),
     debugger = parser.getboolean('minpower', 'debugger'),
 
@@ -140,6 +139,8 @@ user_config = DotDict(dict(
         'minpower', 'ignore_minhours_constraints'),
     ignore_ramping_constraints = parser.getboolean(
         'minpower', 'ignore_ramping_constraints'),
+    ignore_pmin_constraints = parser.getboolean(
+        'minpower', 'ignore_pmin_constraints'),
 
     # HACKs to help out resetting the config in testing
     directory = parser.get('minpower', 'directory'),
