@@ -391,19 +391,13 @@ class OptimizationProblem(OptimizationObject):
             self.solution_time =elapsed #results.Solver[0]['Wallclock time']
             logging.info('Problem solved in {}s.'.format(self.solution_time))
         
-        if user_config.problem_filename:
-            # disable coopr's funny loggings when writing lp files.  
-            logging.getLogger().setLevel(logging.CRITICAL) 
-            self.write_model(full_filename(user_config.problem_filename))
-            logging.getLogger().setLevel(user_config.logging_level)
-                
+        if user_config.problem_file:
+            self.write_model(full_filename('problem.lp'))
+                            
         if not self.solved:
-            if user_config.problem_filename:
-                if self.stochastic_formulation: 
-                    self._stochastic_instance.pprint(full_filename(
-                        'unsolved-stochastic-instance.txt'))
-                self.write_model(full_filename(
-                    'unsolved-problem-formulation.lp'))
+            if user_config.problem_file and self.stochastic_formulation: 
+                self._stochastic_instance.pprint(full_filename(
+                    'unsolved-stochastic-instance.txt'))
             raise OptimizationError('problem not solved')
         
         instance.load(results, 
