@@ -22,12 +22,12 @@ class Load(OptimizationObject):
     Currently only real power is considered.
     For OPF problems, the name of the bus can.
     For UC problems, schedules (pandas.Series objects) are used.
-    By setting `shedding_allowed`, the amount of power can become a variable,
+    By setting `sheddingallowed`, the amount of power can become a variable,
         (bounded to be at most the scheduled amount).
     """
     def __init__(self,
         name='', index=None, bus=None, schedule=None,
-        shedding_allowed=True,
+        sheddingallowed=True,
         cost_shedding=user_config.cost_load_shedding
         ):
         update_attributes(self,locals()) #load in inputs
@@ -350,8 +350,7 @@ class PowerSystem(OptimizationProblem):
                 instance = self.solve()
             except OptimizationError:
                 scheduled, committed = self.debug_infeasibe(times)
-                set_trace()
-                raise OptimizationError('failed to solve with load shedding.')
+                raise OptimizationError('failed to solve withs shedding.')
         return instance
 
     def resolve_stochastic_with_observed(self, instance, sln):
@@ -367,13 +366,10 @@ class PowerSystem(OptimizationProblem):
         sln._get_costs(resolve=True)
 
         self.is_stochastic = True
+        self.disallow_shedding()
         return
 
     def resolve_determinisitc_with_observed(self, sln):
-        # expectP = sln.gen_time_df('power', False)
-        # expectU = sln.gen_time_df('status', False).astype(int)
-        self._resolve_problem(sln)
-
         # store the useful expected value solution information
         sln.expected_status = sln.generators_status.copy()
         sln.expected_power = sln.generators_power.copy()
@@ -381,17 +377,22 @@ class PowerSystem(OptimizationProblem):
         sln.expected_totalcost = sln.totalcost_generation.copy()
         sln.expected_load_shed = float(sln.load_shed)
 
+        # resolve the problem
+        self._resolve_problem(sln)
+
         # re-calc the generator outputs and costs
         sln._get_outputs()
         sln._get_costs()
 
         sln.observed_fuelcost = sln.fuelcost
         sln.observed_totalcost = sln.totalcost_generation
+        self.disallow_shedding()
         return
 
     def _set_load_shedding(self, to_mode):
         '''set system mode for load shedding'''
-        for load in self.loads():
+        for load in filter(lambda ld:
+            ld.sheddingallowed, self.loads()):
             load.shedding_mode = to_mode
 
     def _set_gen_shedding(self, to_mode):
@@ -414,7 +415,8 @@ class PowerSystem(OptimizationProblem):
         
         for gen in filter(lambda g: 
             getattr(g, 'shedding_mode', False), self.generators()):
-            gen.create_variables(times)
+            # create only the power_used var, don't reset the power param
+            gen.create_variables_shedding(times) 
             gen.create_constraints(const_times)
         
         # recalc the power balance constraint
@@ -456,9 +458,7 @@ class PowerSystem(OptimizationProblem):
         
         # set wind to observed power
         gen = self.get_generator_with_observed()
-        wind_power = gen.power(time=None)
-        for time in times:
-            wind_power[time] = gen.observed_values[time]
+        gen.set_power_to_observed(times)
 
         # fix statuses for all units
         self.fix_binary_variables()
@@ -470,31 +470,43 @@ class PowerSystem(OptimizationProblem):
         try: self.solve()
         except OptimizationError:
             if user_config.faststart_resolve:
-                # allow faststart units to be started up to meet the load
-                self._unfix_variables()
-                self._fix_non_faststarts(sln.times)
-                logging.warning('allowing fast-starting units')
-                try: self.solve()
-                except OptimizationError:
-                    self._unfix_variables()
-                    self._fix_non_faststarts(sln.times, fix_power=False)
-                    logging.warning('''allowing non fast-starters
-                        to change power output''')
-                    try: self.solve()
-                    except OptimizationError:
-                        logging.warning('allowing load shedding')
-                        self.allow_shedding(sln.times, resolve=True)
-                        self.solve()
+                self._resolve_with_faststarts(sln)
             else:
                 # just shed the un-meetable load and calculate cost later
                 self.allow_shedding(sln.times, resolve=True)
-                self.solve()
+                try: self.solve()
+                except OptimizationError:
+                    scheduled, committed = self.debug_infeasibe(
+                        sln.times, resolve_sln=sln)
+                    raise
         
         self.resolve_solution_time = self.solution_time
         self.solution_time = self.full_sln_time
         logging.info('resolved instance with observed values (in {}s)'.format(
             self.resolve_solution_time))
-            
+
+    def _resolve_with_faststarts(self, sln):
+        '''allow faststart units to be started up to meet the load'''
+        self._unfix_variables()
+        self._fix_non_faststarts(sln.times)
+        logging.warning('allowing fast-starting units')
+        try: self.solve()
+        except OptimizationError:
+            self._unfix_variables()
+            self._fix_non_faststarts(sln.times, fix_power=False)
+            logging.warning(
+                'allowing non fast-starters to change power output')
+            try: self.solve()
+            except OptimizationError:
+                logging.warning('allowing load shedding')
+                self.allow_shedding(sln.times, resolve=True)
+                try: self.solve()
+                except OptimizationError:
+                    scheduled, committed = self.debug_infeasibe(
+                        sln.times, resolve_sln=sln)
+                    raise
+                
+                
     def _fix_non_faststarts(self, times, fix_power=True):
         '''
         fix non-faststart units - both power and status
@@ -507,22 +519,53 @@ class PowerSystem(OptimizationProblem):
             for time in times:
                 gen.status(time).fixed = True
                 if fix_power: gen.power(time).fixed = True
-    def debug_infeasibe(self, times):
-        scheduled = pd.DataFrame({
-            'load': self.total_scheduled_load().ix[times.strings.values], 
-            'generation': self.total_scheduled_generation().ix[times.strings.values]})
-        scheduled['net_required'] = scheduled['load'] - scheduled.generation
-        
+
+
+    def debug_infeasibe(self, times, resolve_sln=None):
+        generators = self.generators()
+        if resolve_sln: 
+            windgen = self.get_generator_with_observed()
+            
+            scheduled = pd.DataFrame({
+                'expected_power': resolve_sln.generators_power.sum(axis=1).values,
+                'expected_wind': windgen.schedule.ix[times.non_overlap()],
+                'observed_wind': windgen.observed_values.ix[times.non_overlap()],
+                })
+            scheduled['net_required'] = \
+                scheduled.expected_wind - scheduled.observed_wind
+        else:                
+            scheduled = pd.DataFrame({
+                'load': self.total_scheduled_load().ix[times.strings.values], 
+                'generation': self.total_scheduled_generation().ix[times.strings.values]})
+            scheduled['net_required'] = scheduled['load'] - scheduled.generation        
         print 'total scheduled\n', scheduled
-        gens = filter(lambda gen: \
-            gen.is_controllable and gen.initial_status == 1,
-            self.generators())
-        committed = pd.Series(dict(
-            Pmin=sum(gen.pmin for gen in gens),
-            Pmax=sum(gen.pmax for gen in gens),
-            rampratemin=sum(gen.rampratemin for gen in gens),
-            rampratemax=sum(gen.rampratemax for gen in gens),
-            ))
-        print 'total committed\n', committed
         
+        if resolve_sln:
+            committed = pd.DataFrame(dict(
+                Pmin=[gen.pmin for gen in generators],
+                Pmax=[gen.pmax for gen in generators],
+                rampratemin=[getattr(gen, 'rampratemin', None) for gen in generators],
+                rampratemax=[getattr(gen, 'rampratemax', None) for gen in generators],
+                )).T
+            print 'generator limits\n', committed
+        else:
+            gens = filter(lambda gen: \
+                gen.is_controllable and gen.initial_status == 1,
+                self.generators())
+            committed = pd.Series(dict(
+                Pmin=sum(gen.pmin for gen in gens),
+                Pmax=sum(gen.pmax for gen in gens),
+                rampratemin=pd.Series(gen.rampratemin for gen in gens).sum(),
+                rampratemax=pd.Series(gen.rampratemax for gen in gens).sum(),
+                ))
+            print 'total committed\n', committed
+
+        if resolve_sln: 
+            print 'expected status\n', resolve_sln.generators_status
+            ep = resolve_sln.generators_power
+            ep['net_required'] = scheduled.net_required.values
+            print 'expected power\n', ep
+        else:
+            print 'initial_status\n'
+            print pd.Series([gen.initial_status for gen in self.generators()])
         return scheduled, committed
